@@ -2,8 +2,8 @@ from models import User
 import factory
 import random
 
-class UserFactory(factory.Factory):
+class UserFactory(factory.DjangoModelFactory):
     FACTORY_FOR = User
 
     graph_id = factory.Sequence(lambda n: n)
-    gender = random.choice(['male','female'])
\ No newline at end of file
+    gender = random.choice(['male','female'])
